package ch.hevs.isi.field;

import ch.hevs.isi.core.DataPoint;
import ch.hevs.isi.core.FloatDataPoint;

import java.util.HashMap;

public abstract class ModbusRegister {
    private int address;

    /**
     * get the address of the modbus register
     * @return address of the modbus register
     */
    public int getAddress() {
        return address;
    }
    private final static HashMap<DataPoint, ModbusRegister> mapOfRegisters = new HashMap<>();

    /**
     * get the modbus register from the desired datapoint
     * @param dp the desired datapoint
     * @return modbus register
     */
    public static ModbusRegister getRegisterFromDatapoint(DataPoint dp){
        return mapOfRegisters.get(dp);
    }
    public void updateMapOfRegisters(DataPoint dp, int address){
        this.address = address;
        mapOfRegisters.put(dp,this);
    }

    /**
     * read periodically each modbus register
     */
    public static void poll(){
        for (ModbusRegister mr : mapOfRegisters.values()){
            mr.read();                              //read all values (registers) of the map
        }
    }
    public abstract void read();        //abstract prototype of the method read
    public abstract void write();       //abstract prototype of the method read
}
